@@ -322,19 +322,37 @@ class Tracker_View(BrowseForm):
 
 
     def get_item_value(self, resource, context, item, column):
-        if column == 'id':
-            id = item.name
-            return id, '%s/;edit' % id
         if column == 'checkbox':
             selected_issues = context.get_form_values('ids') or []
             return item.name, item.name in selected_issues
-        line = get_issue_informations(resource, item)
+        if column == 'id':
+            id = item.name
+            return id, '%s/;edit' % id
+
+        value = getattr(item, column)
+        if value is None:
+            return None
         if column == 'title':
-            # Add link to title
-            link = '%s/;edit' % item.name
-            return (line['title'], link)
-        if column in line:
-            return line[column]
+            return value, '%s/;edit' % item.name
+        # Assigned to
+        if column == 'assigned_to':
+            users = resource.get_resource('/users')
+            try:
+                user = users.get_resource(value)
+            except LookupError:
+                return None
+            return user.get_title()
+        # Mtime
+        if column == 'mtime':
+            mtime = datetime.strptime(value, '%Y%m%d%H%M%S')
+            return format_datetime(mtime)
+
+        # Tables
+        table = resource.get_resource(column).handler
+        table_record = table.get_record(value)
+        if table_record is None:
+            return None
+        return table.get_record_value(table_record, 'title')
 
 
     table_actions = []
@@ -441,7 +459,7 @@ class Tracker_RememberSearch(BaseForm):
     access = 'is_allowed_to_edit'
     schema = merge_dics(StoredSearchFile.schema,
                         search_name=String,
-                        search_title=Unicode)
+                        search_title=Unicode(mandatory=True))
 
 
     def GET(self, resource, context):
@@ -451,18 +469,37 @@ class Tracker_RememberSearch(BaseForm):
 
     def action(self, resource, context, form):
         search_name = form.get('search_name')
+        title = form['search_title']
+
+        # Already a search name ?
+
+        # No
         if search_name is None:
-            # New search
-            search_name = resource.get_new_id('s')
-            search = StoredSearch.make_resource(StoredSearch, resource,
-                                                search_name)
-            message = MSG(u'The search has been stored.')
+            # Search for a search with the same title
+            if isinstance(resource, Issue):
+                resource = resource.parent
+            searches = resource.search_resources(cls=StoredSearch)
+            for search in searches:
+                # Found !
+                if title == search.get_property('title'):
+                    search_name = search.name
+                    message = MSG(u'The search has been modified.')
+                    break
+            else:
+                # Not found => so we make a new search resource
+                search_name = resource.get_new_id('s')
+                search = StoredSearch.make_resource(StoredSearch, resource,
+                                                    search_name)
+                message = MSG(u'The search has been stored.')
+        # Yes
         else:
             search = resource.get_resource(search_name)
             message = MSG(u'The search title has been changed.')
 
+        # Reset the search
+        search.handler.load_state_from_string('')
+
         # Set title
-        title = form['search_title']
         search.set_property('title', title)
 
         # Save the value
@@ -672,6 +709,7 @@ class Tracker_ChangeSeveralBugs(Tracker_View):
 
 
     def get_namespace(self, resource, context):
+        context.scripts.append('/ui/tracker/tracker.js')
         namespace = Tracker_View.get_namespace(self, resource, context)
         # Edit several bugs at once
         get_resource = resource.get_resource
@@ -682,6 +720,7 @@ class Tracker_ChangeSeveralBugs(Tracker_View):
         namespace['types'] = get_resource('type').get_options()
         namespace['states'] = get_resource('state').get_options()
         namespace['users'] = resource.get_members_namespace('')
+        namespace['list_products'] = resource.get_list_products_namespace()
 
         # Ok
         return namespace
